.BG
.FN phtnnet
.TL
Fit Time-Varying Survival Models
.DN
Fits a time-varying survival model using the output of a neural net
.CS
phtnnet.formula(formula, data=NULL, ...,
               subset, na.action=na.fail, contrasts=NULL)
phtnnet.default(x, status, size,  Wts, mask, skip=F, rang=0.7, 
               decay=0, bias.decay=1, breakpts, MaxNWts=1000,
               maxit=100, trace=T, dohaz=F, dohess=F)
.RA
.AG formula
A formula of the form ` Response ~ x1 + x2 + ...'.  See details below
for required form.
.AG x
matrix or data frame of `x' values for examples.  
See details below for treatment of the time zone variable.
.AG status
Survival time and censoring indicator.  See details below for options.
.AG size
number of units in the hidden layer. Can be zero if there are skip-layer units.
.OA
.AG data
Data frame from which variables specified in  `formula' are
preferentially to be taken.
.AG subset
An index vector specifying the cases to be used in the training
sample.  (NOTE: If given, this argument must be named.)
.AG na.action
A function to specify the action to be taken if `NA's are found.
The default action is for the procedure to fail.  An alternative is
`na.omit', which leads to rejection of cases with missing values on
any required variable.  (NOTE: If given, this argument must be named.)
.AG contrasts
a list of contrasts to be used for some or all  of
the  factors  appearing as variables in the model formula.
.AG Wts
initial parameter vector. If missing chosen at random.
.AG mask
vector used to indicate which weights should be varied.
.AG skip
switch to add skip-layer connections from input to output.
.AG rang
Initial random weights on `[-rang, rang]'.  Value about 0.5 unless the 
inputs are large, in which case it should be chosen so that 
`rang * max(|x|)' is about 1.  See details below for note on scaling of data.
.AG decay
parameter for weight decay.  Default 0.  May be a single value to be used for 
all weights, or a vector 
the same length as the weights vector.
.AG bias.decay
factor by which to divide the weight decay for weights from the bias unit. 
(Easy way to use two values of weight decay only).
.AG breakpts
Break points to use on the survival time to create time zones.  If present,
the `Response' or `status' must contain the survival time, and
`breakpts' must cover all the data.
.AG MaxNWts
The maximum allowable number of weights.  There is no intrinsic limit
in the code, but increasing `MaxNWts' will probably allow fits that are
very slow and time-consuming (and perhaps uninterruptable under
Windows).
.AG maxit
maximum number of iterations. Default 100.
.AG trace
switch for tracing optimization. Default `True'.
.AG dohaz
If true, the cumulative hazard function estimated at the best set of weights
is returned as component `haz'.
.AG dohess
If true, the Hessian of the measure of fit at the best set of weights
found is returned as component `hess'.
.AG ...
further arguments passed to the default method.
.RT
Object of class `"phtnnet.formula"' or `"phtnnet"' (inherits from `"phnnet"'), 
with components
.RC wts
the best set of weights found
.RC value
value of fitting criterion plus weight decay term.
.RC fitted.values
the fitted values for the training data.  This will have a score for each 
time zone for each example.
.DT
A neural network is used to fit a function of the covariates in a
time-varying model. The model essentially allows the ratios of a
proportional hazards model to vary smoothly over time.  The code is
based on nnet, but with significant changes since the partial
likelihood is not a sum over examples. Note that case weights are not
currently available.
.PP
The time zone for each example may be specified in one of two ways:
using the `breakpts' argument or using the final column of the data
matrix, which should then contain appropriately scaled zone values.
(N.B. care must be taken that the use of a formula does not alter the
order of your variables.)  To use the `breakpts' argument, the
survival times must be supplied using `Surv(time,event)' (or equivalent)
as the `status' argument or as the `Response' in the formula.  The
survival times must also be supplied if the data are not sorted in
decreasing order of survival time.  When `breakpts' is used, the time
zones will be scaled to lie in the interval [0,1].
.PP
There is no bias on the output layer: the total number of weights
includes this one, but it is not used.
.PP
A quasi-Newton optimizer is used, written in `C'.
.SH REFERENCES
Ripley R. M. (1998) "`survnnet': Neural network survival models." Part of
documentation of this package.
.SA
`predict.phtnnet', `phtnnet.Hess', `phnnet',  `nnet'
.EX
mylung <- apply(lung[,4:10],2,function(x)(x-min(x,na.rm=T))/
		(range(x,na.rm=T)[2]-range(x,na.rm=T)[1])) 
mylung <- cbind(lung[,1:3],mylung) 
mylung$status <- mylung$status-1    
            
phtfit <-  phtnnet(Surv(time,status)   ~ ., data=mylung[,-1], decay = 0.01, 
		   size = 2, skip=T, trace = T,maxit=1000,dohess=T,
		   breakpts=c(0,100,200,300,10000))
.KW neural
.WR
