.BG
.FN survnnet
.TL
Fit Survival Neural Networks
.DN
Fit neural network models for survival data.
.CS
survnnet.formula(formula, data=NULL, weights, ...,
                subset, na.action=na.fail, contrasts=NULL)
survnnet.default(x, y, weights, size, Wts, mask=rep(1, length(wts)),
                linout=F, entropy=F, softmax=F, censored=F, 
                skip=F, rang=0.7, decay=0, bias.decay=1, maxit=100, Hess=F, 
                trace=T, MaxNWts=1000, 
                model=NULL, alpha=NULL)
.RA
.AG formula
A formula of the form `Response ~ x1 + x2 + ...'. 
For parametric survival models must be  Surv(Time, Event) or equivalent.
.AG x
matrix or data frame of `x' values for examples.
.AG y
matrix or data frame of target values for examples.  For parametric survival 
networks, this must be the survival time followed by the censoring indicator 
(0 for censored, 1 for event).
.AG weights
(case) weights for each example -- if missing defaults to 1.
.AG size
number of units in the hidden layer. Can be zero if there are skip-layer units.
.OA
.AG data
Data frame from which variables specified in  `formula' are
preferentially to be taken.
.AG subset
An index vector specifying the cases to be used in the training
sample.  (NOTE: If given, this argument must be named.)
.AG na.action
A function to specify the action to be taken if `NA's are found.
The default action is for the procedure to fail.  An alternative is
na.omit, which leads to rejection of cases with missing values on
any required variable.  (NOTE: If given, this argument must be named.)
.AG contrasts
a list of contrasts to be used for some or all of
the factors appearing as variables in the model formula.
.AG Wts
initial parameter vector. If missing chosen at random.
.AG mask
vector used to indicate which weights should be varied.
.AG linout
switch for linear output units. Default logistic output units. 
For parametric survival models will be set to linear automatically.
.AG entropy
switch for entropy (= maximum conditional likelihood) fitting. 
Set automatically for parametric survival models. 
 Otherwise default is least-squares.
.AG softmax
switch for softmax (log-linear model) and maximum conditional
likelihood fitting. `linout', `entropy', `softmax' and `censored' are mutually
exclusive.  Set automatically for parametric survival models.
.AG censored
A variant on `softmax', in which non-zero targets mean possible
classes. Thus for `softmax' a row of `(0, 1, 1)' means one example
each of classes 2 and 3, but for `censored' it means one example whose
class is only known to be 2 or 3. Not used for parametric survival models.
.AG skip
switch to add skip-layer connections from input to output.
.AG rang
Initial random weights on `[-rang, rang]'.  Value about 0.5 unless the 
inputs are large, in which case it should be chosen so that 
`rang * max(|x|)' is about 1.
.AG decay
parameter for weight decay.  Default 0.  Can be a single number or a vector 
the same length as the weights vector.
.AG bias.decay
parameter to allow scaling of the weight decay for bias units.  Defaults to 1
which has no effect.  Decay for any weights from the bias units will be divided
by this value.
.AG maxit
maximum number of iterations. Default 100.
.AG Hess
If true, the Hessian of the measure of fit at the best set of weights
found is returned as component `Hessian'.
.AG trace
switch for tracing optimization. Default `True'.
.AG MaxNWts
The maximum allowable number of weights.  There is no intrinsic limit
in the code, but increasing `MaxNWts' will probably allow fits that
are very slow and time-consuming (and perhaps uninterruptable under Windows).
.AG model
Name of parametric model to be used, if any: one of  `"exp"',
`"weibull"', `"llog"', or `"lnorm"'. 
.AG alpha
For parametric survival models only, starting value for the shape parameter. 
 Not used for the exponential model.
.AG ...
further arguments passed to the default method.
.RT
object of class `"survnnet.formula"' or `"survnnet"'  with components
.RC wts
the best set of weights found
.RC value
value of fitting criterion plus weight decay term.
.RC fitted.values
the fitted values for the training data.
.RC alpha
for parametric survival fits, the final value of the shape parameter 
.DT
Fits various feed-forward neural nets. 
Discrete time survival models can be fitted using the entropy, 
softmax and censored options. Parametric survival nets fit 
survival distributions (options are exponential, Weibull,
log-logistic and log-normal).   Based on nnet,
which may be faster for softmax, entropy and sum of squares
fitting.  For proportional hazard models see `phnnet'.
.PP
If the response in `formula' is a factor, an appropriate
classification network is constructed; this has one output and entropy
fit if the number of levels is two, and a number of outputs equal to
the number of classes and a softmax output stage for more levels.  If
the response is not a factor, it is passed on unchanged to
`nnet.default'.  For parametric survival models the response in
`formula' must be a Surv object (or equivalent).
.PP
Some of the formulae for the survival likelihoods are difficult to
evaluate with large values of the data, so it is important to scale
the data sufficiently.  Nets with no hidden units should find weights
equal to the coefficents in the equivalent `survreg' fit, (but with
opposite signs): this can be used as a check on the scaling.
.PP
A quasi-Newton optimizer is used, written in `C'.
.SH REFERENCES
R. M. Ripley (1998) "`survnnet': Neural network survival models." 
Part of documentation of this package.
.SA
`predict.survnnet', `survnnet.Hess', `nnet', `phnnet', `survreg'
.EX
mycap <- capacitor
mycap$voltage <- (mycap$voltage-min(mycap$voltage,na.rm=T))/
  (range(mycap$voltage,na.rm=T)[2]-range(mycap$voltage,na.rm=T)[1])

wei <- survnnet(Surv(days,event) ~ voltage, data=mycap,decay = 0.01,
                size = 2, trace = T, skip = T, model = 'weibull', 
                alpha = 0.1, maxit=100)
.KW neural
.WR
